@@ -213,13 +213,6 @@ options:
     type: bool
     default: "no"
     version_added: "2.7"
-  install_repoquery:
-    description:
-      - This is effectively a no-op in DNF as it is not needed with DNF.
-      - This option is deprecated and will be removed in ansible-core 2.20.
-    type: bool
-    default: "yes"
-    version_added: "2.7"
   download_only:
     description:
       - Only download the packages, do not install them.
@@ -544,6 +537,9 @@ class DnfModule(YumDnf):
         conf.sslverify = sslverify
 
         # Set installroot
+        if not os.path.isdir(installroot):
+            self.module.fail_json(msg=f"Installroot {installroot} must be a directory")
+
         conf.installroot = installroot
 
         # Load substitutions from the filesystem
