@@ -6,7 +6,7 @@
 from __future__ import annotations
 
 
-DOCUMENTATION = '''
+DOCUMENTATION = """
 ---
 module: group
 version_added: "0.0.2"
@@ -37,7 +37,7 @@ options:
     force:
         description:
             - Whether to delete a group even if it is the primary group of a user.
-            - Only applicable on platforms which implement a --force flag on the group deletion command.
+            - Only applicable on platforms which implement a C(--force) flag on the group deletion command.
         type: bool
         default: false
         version_added: "2.15"
@@ -62,6 +62,22 @@ options:
         type: bool
         default: no
         version_added: "2.8"
+    gid_min:
+        description:
+            - Sets the GID_MIN value for group creation.
+            - Overwrites /etc/login.defs default value.
+            - Currently supported on Linux. Does nothing when used with other platforms.
+            - Requires O(local) is omitted or V(False).
+        type: int
+        version_added: "2.18"
+    gid_max:
+        description:
+            - Sets the GID_MAX value for group creation.
+            - Overwrites /etc/login.defs default value.
+            - Currently supported on Linux. Does nothing when used with other platforms.
+            - Requires O(local) is omitted or V(False).
+        type: int
+        version_added: "2.18"
 extends_documentation_fragment: action_common_attributes
 attributes:
     check_mode:
@@ -75,9 +91,9 @@ seealso:
 - module: ansible.windows.win_group
 author:
 - Stephen Fromm (@sfromm)
-'''
+"""
 
-EXAMPLES = '''
+EXAMPLES = """
 - name: Ensure group "somegroup" exists
   ansible.builtin.group:
     name: somegroup
@@ -88,9 +104,9 @@ EXAMPLES = '''
     name: docker
     state: present
     gid: 1750
-'''
+"""
 
-RETURN = r'''
+RETURN = r"""
 gid:
   description: Group ID of the group.
   returned: When O(state) is C(present)
@@ -111,7 +127,7 @@ system:
   returned: When O(state) is C(present)
   type: bool
   sample: False
-'''
+"""
 
 import grp
 import os
@@ -151,6 +167,14 @@ class Group(object):
         self.system = module.params['system']
         self.local = module.params['local']
         self.non_unique = module.params['non_unique']
+        self.gid_min = module.params['gid_min']
+        self.gid_max = module.params['gid_max']
+
+        if self.local:
+            if self.gid_min is not None:
+                module.fail_json(msg="'gid_min' can not be used with 'local'")
+            if self.gid_max is not None:
+                module.fail_json(msg="'gid_max' can not be used with 'local'")
 
     def execute_command(self, cmd):
         return self.module.run_command(cmd)
@@ -184,6 +208,12 @@ class Group(object):
                     cmd.append('-o')
             elif key == 'system' and kwargs[key] is True:
                 cmd.append('-r')
+        if self.gid_min is not None:
+            cmd.append('-K')
+            cmd.append('GID_MIN=' + str(self.gid_min))
+        if self.gid_max is not None:
+            cmd.append('-K')
+            cmd.append('GID_MAX=' + str(self.gid_max))
         cmd.append(self.name)
         return self.execute_command(cmd)
 
@@ -292,6 +322,12 @@ class SunOS(Group):
                 cmd.append(str(kwargs[key]))
                 if self.non_unique:
                     cmd.append('-o')
+        if self.gid_min is not None:
+            cmd.append('-K')
+            cmd.append('GID_MIN=' + str(self.gid_min))
+        if self.gid_max is not None:
+            cmd.append('-K')
+            cmd.append('GID_MAX=' + str(self.gid_max))
         cmd.append(self.name)
         return self.execute_command(cmd)
 
@@ -323,6 +359,12 @@ class AIX(Group):
                 cmd.append('id=' + str(kwargs[key]))
             elif key == 'system' and kwargs[key] is True:
                 cmd.append('-a')
+        if self.gid_min is not None:
+            cmd.append('-K')
+            cmd.append('GID_MIN=' + str(self.gid_min))
+        if self.gid_max is not None:
+            cmd.append('-K')
+            cmd.append('GID_MAX=' + str(self.gid_max))
         cmd.append(self.name)
         return self.execute_command(cmd)
 
@@ -368,6 +410,12 @@ class FreeBsdGroup(Group):
             cmd.append(str(self.gid))
             if self.non_unique:
                 cmd.append('-o')
+        if self.gid_min is not None:
+            cmd.append('-K')
+            cmd.append('GID_MIN=' + str(self.gid_min))
+        if self.gid_max is not None:
+            cmd.append('-K')
+            cmd.append('GID_MAX=' + str(self.gid_max))
         return self.execute_command(cmd)
 
     def group_mod(self, **kwargs):
@@ -492,6 +540,12 @@ class OpenBsdGroup(Group):
             cmd.append(str(self.gid))
             if self.non_unique:
                 cmd.append('-o')
+        if self.gid_min is not None:
+            cmd.append('-K')
+            cmd.append('GID_MIN=' + str(self.gid_min))
+        if self.gid_max is not None:
+            cmd.append('-K')
+            cmd.append('GID_MAX=' + str(self.gid_max))
         cmd.append(self.name)
         return self.execute_command(cmd)
 
@@ -538,6 +592,12 @@ class NetBsdGroup(Group):
             cmd.append(str(self.gid))
             if self.non_unique:
                 cmd.append('-o')
+        if self.gid_min is not None:
+            cmd.append('-K')
+            cmd.append('GID_MIN=' + str(self.gid_min))
+        if self.gid_max is not None:
+            cmd.append('-K')
+            cmd.append('GID_MAX=' + str(self.gid_max))
         cmd.append(self.name)
         return self.execute_command(cmd)
 
@@ -578,6 +638,14 @@ class BusyBoxGroup(Group):
         if self.system:
             cmd.append('-S')
 
+        if self.gid_min is not None:
+            cmd.append('-K')
+            cmd.append('GID_MIN=' + str(self.gid_min))
+
+        if self.gid_max is not None:
+            cmd.append('-K')
+            cmd.append('GID_MAX=' + str(self.gid_max))
+
         cmd.append(self.name)
 
         return self.execute_command(cmd)
@@ -626,6 +694,8 @@ def main():
             system=dict(type='bool', default=False),
             local=dict(type='bool', default=False),
             non_unique=dict(type='bool', default=False),
+            gid_min=dict(type='int'),
+            gid_max=dict(type='int'),
         ),
         supports_check_mode=True,
         required_if=[
