@@ -10,7 +10,7 @@
 from __future__ import annotations
 
 
-DOCUMENTATION = r'''
+DOCUMENTATION = r"""
 ---
 module: unarchive
 version_added: '1.4'
@@ -150,9 +150,9 @@ seealso:
 - module: community.general.iso_extract
 - module: community.windows.win_unzip
 author: Michael DeHaan
-'''
+"""
 
-EXAMPLES = r'''
+EXAMPLES = r"""
 - name: Extract foo.tgz into /var/lib/foo
   ansible.builtin.unarchive:
     src: foo.tgz
@@ -177,9 +177,9 @@ EXAMPLES = r'''
     extra_opts:
     - --transform
     - s/^xxx/yyy/
-'''
+"""
 
-RETURN = r'''
+RETURN = r"""
 dest:
   description: Path to the destination directory.
   returned: always
@@ -237,10 +237,11 @@ uid:
   returned: always
   type: int
   sample: 1000
-'''
+"""
 
 import binascii
 import codecs
+import ctypes
 import fnmatch
 import grp
 import os
@@ -249,7 +250,6 @@ import pwd
 import re
 import stat
 import time
-import traceback
 from functools import partial
 from zipfile import ZipFile
 
@@ -262,6 +262,13 @@ from ansible.module_utils.urls import fetch_file
 from shlex import quote
 from zipfile import BadZipFile
 
+try:
+    from functools import cache
+except ImportError:
+    # Python < 3.9
+    from functools import lru_cache
+    cache = lru_cache(maxsize=None)
+
 # String from tar that shows the tar contents are different from the
 # filesystem
 OWNER_DIFF_RE = re.compile(r': Uid differs$')
@@ -279,8 +286,20 @@ CONTENT_DIFF_RE = re.compile(r': Contents differ$')
 SIZE_DIFF_RE = re.compile(r': Size differs$')
 
 
+@cache
+def _y2038_impacted():
+    """Determine if the system has 64-bit time_t."""
+    if hasattr(ctypes, "c_time_t"):  # Python >= 3.12
+        return ctypes.sizeof(ctypes.c_time_t) < 8
+    try:
+        time.gmtime(2**31)
+    except OverflowError:
+        return True
+    return False
+
+
 def crc32(path, buffer_size):
-    ''' Return a CRC32 checksum of a file '''
+    """ Return a CRC32 checksum of a file """
 
     crc = binascii.crc32(b'')
     with open(path, 'rb') as f:
@@ -290,7 +309,7 @@ def crc32(path, buffer_size):
 
 
 def shell_escape(string):
-    ''' Quote meta-characters in the args for the unix shell '''
+    """ Quote meta-characters in the args for the unix shell """
     return re.sub(r'([^A-Za-z0-9_])', r'\\\1', string)
 
 
@@ -321,7 +340,7 @@ class ZipArchive(object):
         )
 
     def _permstr_to_octal(self, modestr, umask):
-        ''' Convert a Unix permission string (rw-r--r--) into a mode (0644) '''
+        """ Convert a Unix permission string (rw-r--r--) into a mode (0644) """
         revstr = modestr[::-1]
         mode = 0
         for j in range(0, 3):
@@ -414,6 +433,8 @@ class ZipArchive(object):
             try:
                 if int(match.groups()[0]) < 1980:
                     date_time = epoch_date_time
+                elif int(match.groups()[0]) >= 2038 and _y2038_impacted():
+                    date_time = (2038, 1, 1, 0, 0, 0, 0, 0, 0)
                 elif int(match.groups()[0]) > 2107:
                     date_time = (2107, 12, 31, 23, 59, 59, 0, 0, 0)
                 else:
@@ -676,7 +697,7 @@ class ZipArchive(object):
                             try:
                                 mode = AnsibleModule._symbolic_mode_to_octal(st, self.file_args['mode'])
                             except ValueError as e:
-                                self.module.fail_json(path=path, msg="%s" % to_native(e), exception=traceback.format_exc())
+                                self.module.fail_json(path=path, msg="%s" % to_native(e))
                 # Only special files require no umask-handling
                 elif ztype == '?':
                     mode = self._permstr_to_octal(permstr, 0)
@@ -1111,8 +1132,8 @@ def main():
             res_args['extract_results'] = handler.unarchive()
             if res_args['extract_results']['rc'] != 0:
                 module.fail_json(msg="failed to unpack %s to %s" % (src, dest), **res_args)
-        except IOError:
-            module.fail_json(msg="failed to unpack %s to %s" % (src, dest), **res_args)
+        except OSError as ex:
+            module.fail_json(f"Failed to unpack {src!r} to {dest!r}.", exception=ex, **res_args)
         else:
             res_args['changed'] = True
 
@@ -1129,8 +1150,8 @@ def main():
 
             try:
                 res_args['changed'] = module.set_fs_attributes_if_different(file_args, res_args['changed'], expand=False)
-            except (IOError, OSError) as e:
-                module.fail_json(msg="Unexpected error when accessing exploded file: %s" % to_native(e), **res_args)
+            except OSError as ex:
+                module.fail_json("Unexpected error when accessing exploded file.", exception=ex, **res_args)
 
             if '/' in filename:
                 top_folder_path = filename.split('/')[0]
@@ -1144,8 +1165,8 @@ def main():
                 file_args['path'] = "%s/%s" % (dest, f)
                 try:
                     res_args['changed'] = module.set_fs_attributes_if_different(file_args, res_args['changed'], expand=False)
-                except (IOError, OSError) as e:
-                    module.fail_json(msg="Unexpected error when accessing exploded file: %s" % to_native(e), **res_args)
+                except OSError as ex:
+                    module.fail_json("Unexpected error when accessing exploded file.", exception=ex, **res_args)
 
     if module.params['list_files']:
         res_args['files'] = handler.files_in_archive
