@@ -3,7 +3,7 @@
 
 from __future__ import annotations
 
-DOCUMENTATION = '''
+DOCUMENTATION = """
     inventory: statichost
         broken:
     short_description: Add a single host
@@ -17,7 +17,7 @@ DOCUMENTATION = '''
       hostname:
         description: Toggle display of stderr even when script was successful
         required: True
-'''
+"""
 
 from ansible.plugins.inventory import BaseInventoryPlugin, Cacheable
 
