@@ -1,10 +1,8 @@
 # (c) 2020 Ansible Project
 # GNU General Public License v3.0+ (see COPYING or https://www.gnu.org/licenses/gpl-3.0.txt)
 
-# Make coding more python3-ish
-from __future__ import (absolute_import, division, print_function)
+from __future__ import annotations
 
-__metaclass__ = type
 
 DOCUMENTATION = """
     lookup: noop
@@ -32,7 +30,8 @@ RETURN = """
     version_added: 1.0.0
 """
 
-from ansible.module_utils.common._collections_compat import Sequence
+from collections.abc import Sequence
+
 from ansible.plugins.lookup import LookupBase
 from ansible.errors import AnsibleError
 
