@@ -1,11 +1,9 @@
 # Copyright: (c) 2022, Ansible Project
 # GNU General Public License v3.0+ (see COPYING or https://www.gnu.org/licenses/gpl-3.0.txt)
 
-from __future__ import (absolute_import, division, print_function)
-__metaclass__ = type
+from __future__ import annotations
 
 from ansible.plugins.action.normal import ActionModule as ActionBase
-from ansible.utils.vars import merge_hash
 
 
 class ActionModule(ActionBase):
