@@ -1,6 +1,6 @@
 #!/usr/bin/env bash
 
-set -ux
+set -eux
 
 cleanup() {
     unlink normal/library/_symlink.py
@@ -35,4 +35,5 @@ done
 # test config loading
 ansible-playbook use_coll_name.yml -i ../../inventory -e 'ansible_connection=ansible.builtin.ssh' "$@"
 
-ANSIBLE_COLLECTIONS_PATH=$PWD/collections ansible-playbook unsafe_plugin_name.yml "$@"
+# test filter loading ignoring duplicate file basename
+ansible-playbook file_collision/play.yml "$@"
