@@ -62,7 +62,6 @@ import os
 from collections.abc import MutableMapping
 
 from ansible.errors import AnsibleError, AnsibleParserError
-from ansible.module_utils.six import string_types
 from ansible.module_utils.common.text.converters import to_native, to_text
 from ansible.plugins.inventory import BaseFileInventoryPlugin
 
@@ -126,7 +125,7 @@ class InventoryModule(BaseFileInventoryPlugin):
                 for section in ['vars', 'children', 'hosts']:
                     if section in group_data:
                         # convert strings to dicts as these are allowed
-                        if isinstance(group_data[section], string_types):
+                        if isinstance(group_data[section], str):
                             group_data[section] = {group_data[section]: None}
 
                         if not isinstance(group_data[section], (MutableMapping, NoneType)):
