@@ -1,4 +1,5 @@
 """Common utility code that depends on CommonConfig."""
+
 from __future__ import annotations
 
 import collections.abc as c
@@ -65,6 +66,7 @@ CHECK_YAML_VERSIONS: dict[str, t.Any] = {}
 
 class ExitHandler:
     """Simple exit handler implementation."""
+
     _callbacks: list[tuple[t.Callable, tuple[t.Any, ...], dict[str, t.Any]]] = []
 
     @staticmethod
@@ -88,7 +90,7 @@ class ExitHandler:
 
                 try:
                     func(*args, **kwargs)
-                except BaseException as ex:  # pylint: disable=broad-except
+                except BaseException as ex:  # pylint: disable=broad-exception-caught
                     last_exception = ex
                     display.fatal(f'Exit handler failed: {ex}')
 
@@ -175,6 +177,7 @@ class CommonConfig:
         self.debug: bool = args.debug
         self.truncate: int = args.truncate
         self.redact: bool = args.redact
+        self.display_traceback: str = args.display_traceback
 
         self.display_stderr: bool = False
 
@@ -269,7 +272,10 @@ def named_temporary_file(args: CommonConfig, prefix: str, suffix: str, directory
             tempfile_fd.write(to_bytes(content))
             tempfile_fd.flush()
 
-            yield tempfile_fd.name
+            try:
+                yield tempfile_fd.name
+            finally:
+                pass
 
 
 def write_json_test_results(
@@ -300,6 +306,7 @@ def get_injector_path() -> str:
     injector_names = sorted(list(ANSIBLE_BIN_SYMLINK_MAP) + [
         'importer.py',
         'pytest',
+        'ansible_connection_cli_stub.py',
     ])
 
     scripts = (
@@ -406,10 +413,10 @@ def create_interpreter_wrapper(interpreter: str, injected_interpreter: str) -> N
     # injected_interpreter could be a script from the system or our own wrapper created for the --venv option
     shebang_interpreter = sys.executable
 
-    code = textwrap.dedent('''
+    code = textwrap.dedent("""
     #!%s
 
-    from __future__ import absolute_import
+    from __future__ import annotations
 
     from os import execv
     from sys import argv
@@ -417,7 +424,7 @@ def create_interpreter_wrapper(interpreter: str, injected_interpreter: str) -> N
     python = '%s'
 
     execv(python, [python] + argv[1:])
-    ''' % (shebang_interpreter, interpreter)).lstrip()
+    """ % (shebang_interpreter, interpreter)).lstrip()
 
     write_text_file(injected_interpreter, code)
 
@@ -444,10 +451,20 @@ def intercept_python(
     """
     Run a command while intercepting invocations of Python to control the version used.
     If the specified Python is an ansible-test managed virtual environment, it will be added to PATH to activate it.
-    Otherwise a temporary directory will be created to ensure the correct Python can be found in PATH.
+    Otherwise, a temporary directory will be created to ensure the correct Python can be found in PATH.
     """
-    env = env.copy()
     cmd = list(cmd)
+    env = get_injector_env(python, env)
+
+    return run_command(args, cmd, capture=capture, env=env, data=data, cwd=cwd, always=always)
+
+
+def get_injector_env(
+    python: PythonConfig,
+    env: dict[str, str],
+) -> dict[str, str]:
+    """Get the environment variables needed to inject the given Python interpreter into the environment."""
+    env = env.copy()
     inject_path = get_injector_path()
 
     # make sure scripts (including injector.py) find the correct Python interpreter
@@ -460,7 +477,7 @@ def intercept_python(
     env['ANSIBLE_TEST_PYTHON_VERSION'] = python.version
     env['ANSIBLE_TEST_PYTHON_INTERPRETER'] = python.path
 
-    return run_command(args, cmd, capture=capture, env=env, data=data, cwd=cwd, always=always)
+    return env
 
 
 def run_command(
@@ -498,9 +515,14 @@ def run_command(
     )
 
 
-def yamlcheck(python: PythonConfig) -> t.Optional[bool]:
+def yamlcheck(python: PythonConfig, explain: bool = False) -> t.Optional[bool]:
     """Return True if PyYAML has libyaml support, False if it does not and None if it was not found."""
-    result = json.loads(raw_command([python.path, os.path.join(ANSIBLE_TEST_TARGET_TOOLS_ROOT, 'yamlcheck.py')], capture=True)[0])
+    stdout = raw_command([python.path, os.path.join(ANSIBLE_TEST_TARGET_TOOLS_ROOT, 'yamlcheck.py')], capture=True, explain=explain)[0]
+
+    if explain:
+        return None
+
+    result = json.loads(stdout)
 
     if not result['yaml']:
         return None
