@@ -27,9 +27,11 @@ import typing as t
 import pytest_mock
 
 from jinja2.runtime import Context
+from jinja2.loaders import DictLoader
 
 import unittest
 
+from ansible._internal import _display_utils
 from ansible._internal._templating._datatag import _JinjaConstTemplate
 from ansible.errors import (
     AnsibleError, AnsibleUndefinedVariable, AnsibleTemplateSyntaxError, AnsibleBrokenConditionalError, AnsibleTemplateError, AnsibleTemplateTransformLimitError,
@@ -51,7 +53,7 @@ from ansible._internal._templating._jinja_bits import AnsibleEnvironment, Ansibl
 from ansible._internal._templating._marker_behaviors import ReplacingMarkerBehavior
 from ansible._internal._templating._utils import TemplateContext
 from ansible.module_utils._internal import _event_utils
-from ansible.utils.display import Display, _DeferredWarningContext
+from ansible.utils.display import Display
 from units.mock.loader import DictDataLoader
 from units.test_utils.controller.display import emits_warnings
 
@@ -1032,7 +1034,7 @@ def test_deprecated_dedupe_and_source():
 
     templar = TemplateEngine(variables=variables)
 
-    with _DeferredWarningContext(variables=variables) as dwc:
+    with _display_utils.DeferredWarningContext(variables=variables) as dwc:
         # The indirect access summary occurs first.
         # The two following direct access summaries get deduped to a single one by the warning context (but unique template value keeps distinct from indirect).
         # The accesses with the shared tag instance values are internally deduped by the audit context.
@@ -1048,14 +1050,14 @@ def test_deprecated_dedupe_and_source():
 
 def test_jinja_const_template_leak(template_context: TemplateContext) -> None:
     """Verify that _JinjaConstTemplate is present during internal templating."""
-    with _DeferredWarningContext(variables={}):  # suppress warning from usage of embedded template
+    with _display_utils.DeferredWarningContext(variables={}):  # suppress warning from usage of embedded template
         with unittest.mock.patch.object(_TemplateConfig, 'allow_embedded_templates', True):
             assert _JinjaConstTemplate.is_tagged_on(TemplateEngine().template(TRUST.tag("{{ '{{ 1 }}' }}")))
 
 
 def test_jinja_const_template_finalized() -> None:
     """Verify that _JinjaConstTemplate is not present in finalized template results."""
-    with _DeferredWarningContext(variables={}):  # suppress warning from usage of embedded template
+    with _display_utils.DeferredWarningContext(variables={}):  # suppress warning from usage of embedded template
         with unittest.mock.patch.object(_TemplateConfig, 'allow_embedded_templates', True):
             assert not _JinjaConstTemplate.is_tagged_on(TemplateEngine().template(TRUST.tag("{{ '{{ 1 }}' }}")))
 
@@ -1078,3 +1080,47 @@ def test_marker_from_test_plugin() -> None:
     """Verify test plugins can raise MarkerError to return a Marker, and that no warnings or deprecations are emitted."""
     with emits_warnings(deprecation_pattern=[], warning_pattern=[]):
         assert TemplateEngine(variables=dict(something=TRUST.tag("{{ nope }}"))).template(TRUST.tag("{{ (something is eq {}) is undefined }}"))
+
+
+@pytest.mark.parametrize("template,expected", (
+    ("{{ none }}", None),  # concat sees one node, NoneType result is preserved
+    ("{% if False %}{% endif %}", None),  # concat sees one node, NoneType result is preserved
+    ("{{''}}{% if False %}{% endif %}", ""),  # multiple blocks with an embedded None result, concat is in play, the result is an empty string
+    ("hey {{ none }}", "hey "),  # composite template, the result is an empty string
+    ("{% import 'importme' as imported %}{{ imported }}", "imported template result"),
+))
+def test_none_concat(template: str, expected: object) -> None:
+    """Validate that None values are omitted from composite template concat."""
+    te = TemplateEngine()
+
+    # set up an importable template to exercise TemplateModule code paths
+    te.environment.loader = DictLoader(dict(importme=TRUST.tag("{{ none }}{{ 'imported template result' }}{{ none }}")))
+
+    assert te.template(TRUST.tag(template)) == expected
+
+
+def test_filter_generator() -> None:
+    """Verify that filters which return a generator are converted to a list while under the filter's JinjaCallContext."""
+    variables = dict(
+        foo=[
+            dict(x=1, optional_var=0),
+            dict(x=2),
+        ],
+        bar=TRUST.tag("{{ foo | selectattr('optional_var', 'defined') }}"),
+    )
+
+    te = TemplateEngine(variables=variables)
+    te.template(TRUST.tag("{{ bar }}"))
+    te.template(TRUST.tag("{{ lookup('vars', 'bar') }}"))
+
+
+def test_call_context_reset() -> None:
+    """Ensure that new template invocations do not inherit trip behavior from running Jinja plugins."""
+    templar = TemplateEngine(variables=dict(
+        somevar=TRUST.tag("{{ somedict.somekey | default('ok') }}"),
+        somedict=dict(
+            somekey=TRUST.tag("{{ not_here }}"),
+        )
+    ))
+
+    assert templar.template(TRUST.tag("{{ lookup('vars', 'somevar') }}")) == 'ok'
