@@ -6,49 +6,50 @@ from __future__ import annotations
 
 import os
 import json
+import pathlib
 
 import pytest
 
 from collections.abc import Mapping
 from datetime import date, datetime, timezone, timedelta
 
-from ansible.parsing.ajson import AnsibleJSONEncoder, AnsibleJSONDecoder
-from ansible.parsing.yaml.objects import AnsibleVaultEncryptedUnicode
-from ansible.utils.unsafe_proxy import AnsibleUnsafeText
+from ansible._internal._json._legacy_encoder import LegacyControllerJSONEncoder
+from ansible.module_utils.common.json import get_encoder, get_decoder
+from ansible.parsing.vault import EncryptedString, AnsibleVaultError
+from ansible._internal._datatag._tags import TrustedAsTemplate
+from ansible._internal._json._profiles import _legacy
 
 
-def test_AnsibleJSONDecoder_vault():
+def test_AnsibleJSONDecoder_vault(_empty_vault_secrets_context):
+    profile = _legacy
+
     with open(os.path.join(os.path.dirname(__file__), 'fixtures/ajson.json')) as f:
-        data = json.load(f, cls=AnsibleJSONDecoder)
+        data = json.load(f, cls=get_decoder(profile))
 
-    assert isinstance(data['password'], AnsibleVaultEncryptedUnicode)
-    assert isinstance(data['bar']['baz'][0]['password'], AnsibleVaultEncryptedUnicode)
-    assert isinstance(data['foo']['password'], AnsibleVaultEncryptedUnicode)
+    assert isinstance(data['password'], EncryptedString)
+    with pytest.raises(AnsibleVaultError):
+        str(data['password'])
 
+    assert isinstance(data['bar']['baz'][0]['password'], EncryptedString)
+    with pytest.raises(AnsibleVaultError):
+        str(data['bar']['baz'][0]['password'])
 
-def test_encode_decode_unsafe():
-    data = {
-        'key_value': AnsibleUnsafeText(u'{#NOTACOMMENT#}'),
-        'list': [AnsibleUnsafeText(u'{#NOTACOMMENT#}')],
-        'list_dict': [{'key_value': AnsibleUnsafeText(u'{#NOTACOMMENT#}')}]}
-    json_expected = (
-        '{"key_value": {"__ansible_unsafe": "{#NOTACOMMENT#}"}, '
-        '"list": [{"__ansible_unsafe": "{#NOTACOMMENT#}"}], '
-        '"list_dict": [{"key_value": {"__ansible_unsafe": "{#NOTACOMMENT#}"}}]}'
-    )
-    assert json.dumps(data, cls=AnsibleJSONEncoder, preprocess_unsafe=True, sort_keys=True) == json_expected
-    assert json.loads(json_expected, cls=AnsibleJSONDecoder) == data
+    assert isinstance(data['foo']['password'], EncryptedString)
+    with pytest.raises(AnsibleVaultError):
+        str(data['foo']['password'])
 
 
 def vault_data():
     """
-    Prepare AnsibleVaultEncryptedUnicode test data for AnsibleJSONEncoder.default().
+    Prepare vault test data for AnsibleJSONEncoder.default().
 
     Return a list of tuples (input, expected).
     """
 
-    with open(os.path.join(os.path.dirname(__file__), 'fixtures/ajson.json')) as f:
-        data = json.load(f, cls=AnsibleJSONDecoder)
+    profile = _legacy
+
+    raw_data = TrustedAsTemplate().tag((pathlib.Path(__file__).parent / 'fixtures/ajson.json').read_text())
+    data = json.loads(raw_data, cls=get_decoder(profile))
 
     data_0 = data['password']
     data_1 = data['bar']['baz'][0]['password']
@@ -117,7 +118,7 @@ class TestAnsibleJSONEncoder:
     @pytest.fixture
     def ansible_json_encoder(self):
         """Return AnsibleJSONEncoder object."""
-        return AnsibleJSONEncoder()
+        return LegacyControllerJSONEncoder()
 
     ###############
     # Test methods:
@@ -142,10 +143,10 @@ class TestAnsibleJSONEncoder:
     @pytest.mark.parametrize(
         'mapping,expected',
         [
-            ({1: 1}, {1: 1}),
-            ({2: 2}, {2: 2}),
-            ({1: 2}, {1: 2}),
-            ({2: 1}, {2: 1}),
+            ({'1': 1}, {'1': 1}),
+            ({'2': 2}, {'2': 2}),
+            ({'1': 2}, {'1': 2}),
+            ({'2': 1}, {'2': 1}),
         ], indirect=['mapping'],
     )
     def test_mapping(self, ansible_json_encoder, mapping, expected):
@@ -155,18 +156,18 @@ class TestAnsibleJSONEncoder:
         assert ansible_json_encoder.default(mapping) == expected
 
     @pytest.mark.parametrize('test_input,expected', vault_data())
-    def test_ansible_json_decoder_vault(self, ansible_json_encoder, test_input, expected):
+    def test_ansible_json_encoder_vault(self, test_input, expected):
         """
-        Test for passing AnsibleVaultEncryptedUnicode to AnsibleJSONEncoder.default().
+        Test for passing vaulted values to AnsibleJSONEncoder.default().
         """
-        assert ansible_json_encoder.default(test_input) == {'__ansible_vault': expected}
-        assert json.dumps(test_input, cls=AnsibleJSONEncoder, preprocess_unsafe=True) == '{"__ansible_vault": "%s"}' % expected.replace('\n', '\\n')
+        profile = _legacy
+        assert json.dumps(test_input, cls=get_encoder(profile)) == '{"__ansible_vault": "%s"}' % expected.replace('\n', '\\n')
 
     @pytest.mark.parametrize(
         'test_input,expected',
         [
-            ({1: 'first'}, {1: 'first'}),
-            ({2: 'second'}, {2: 'second'}),
+            ({'1': 'first'}, {'1': 'first'}),
+            ({'2': 'second'}, {'2': 'second'}),
         ]
     )
     def test_default_encoder(self, ansible_json_encoder, test_input, expected):
@@ -178,12 +179,18 @@ class TestAnsibleJSONEncoder:
         """
         assert ansible_json_encoder.default(test_input) == expected
 
-    @pytest.mark.parametrize('test_input', [1, 1.1, 'string', [1, 2], set('set'), True, None])
-    def test_default_encoder_unserializable(self, ansible_json_encoder, test_input):
-        """
-        Test for the default encoder of AnsibleJSONEncoder.default(), not serializable objects.
 
-        It must fail with TypeError 'object is not serializable'.
-        """
-        with pytest.raises(TypeError):
-            ansible_json_encoder.default(test_input)
+@pytest.mark.parametrize("trust_input_str", (
+    True,
+    False
+))
+def test_string_trust_propagation(trust_input_str: bool) -> None:
+    """Verify that input trust propagation behaves as expected. The presence of trust on the input string determines if trust is applied to outputs."""
+    data = '{"foo": "bar"}'
+
+    if trust_input_str:
+        data = TrustedAsTemplate().tag(data)
+
+    res = json.loads(data, cls=_legacy.Decoder)
+
+    assert trust_input_str == TrustedAsTemplate.is_tagged_on(res['foo'])
