@@ -86,28 +86,28 @@ class TestErrors(unittest.TestCase):
         self.assertPluginLoaderConfigBecomes(None, [])
 
     def test__load_module_source_no_duplicate_names(self):
-        '''
+        """
         This test simulates importing 2 plugins with the same name,
         and validating that the import is short circuited if a file with the same name
         has already been imported
-        '''
+        """
 
         fixture_path = os.path.join(os.path.dirname(__file__), 'loader_fixtures')
 
         pl = PluginLoader('test', '', 'test', 'test_plugin')
-        one = pl._load_module_source('import_fixture', os.path.join(fixture_path, 'import_fixture.py'))
+        one = pl._load_module_source(python_module_name='import_fixture', path=os.path.join(fixture_path, 'import_fixture.py'))
         # This line wouldn't even succeed if we didn't short circuit on finding a duplicate name
-        two = pl._load_module_source('import_fixture', '/path/to/import_fixture.py')
+        two = pl._load_module_source(python_module_name='import_fixture', path='/path/to/import_fixture.py')
 
         self.assertEqual(one, two)
 
     @patch('ansible.plugins.loader.glob')
     @patch.object(PluginLoader, '_get_paths_with_context')
     def test_all_no_duplicate_names(self, gp_mock, glob_mock):
-        '''
+        """
         This test goes along with ``test__load_module_source_no_duplicate_names``
         and ensures that we ignore duplicate imports on multiple paths
-        '''
+        """
 
         fixture_path = os.path.join(os.path.dirname(__file__), 'loader_fixtures')
 
